+++
title = "Isotropy of Parallel Manipulator"
author = ["Thomas Dehaeze"]
draft = false
+++

Tags
: [Stewart Platforms]({{<relref "stewart_platforms.md#" >}})

Here are some notes on the literature about the isotropy of parallel manipulators.


## ([Tsai and Huang 2003](#org838fed0)) {#tsai-and-huang-2003--org838fed0}


## ([Fassi, Legnani, and Tosi 2005](#org2487ba1)) {#fassi-legnani-and-tosi-2005--org2487ba1}


## ([Bandyopadhyay and Ghosal 2008](#org89a27d1)) {#bandyopadhyay-and-ghosal-2008--org89a27d1}

Uses `mathematica` to inverse analytical Jacobian matrix and obtain conditions for isotropy.


## ([Legnani et al. 2010](#orgbf26550)) {#legnani-et-al-dot-2010--orgbf26550}


### Abstract {#abstract}

A manipulator exhibits an _isotropic behaviour_ when it has the same performances along all the directions of the working space.

The authors introduce the new concept of _Point of Isotropy_, showing how in some circumstances a non-isotropic manipulator may be transform into an isotropic one simply changing the location of its Tool Center Point (TCP).


### Introduction {#introduction}

**Kinetostatic** of parallel manipulator can be studied with the following equations:

\begin{align}
  \dot{Q} &= J \dot{S} \\\\\\
  F\_s &= J^T F\_q \\\\\\
  J   &= \frac{\partial Q}{\partial S}
\end{align}

where \\(J\\) is the Jacobian matrix which relates the "gripper" velocity \\(\dot{S}\\) with those of the actuators \\(\dot{Q}\\), as well as the forces \\(F\_q\\) exerted by the actuators with the forces/torques \\(F\_s\\) applied to the gripper.


### Isotropy {#isotropy}

A robot is called **isotropic** if at least in one point of the working space some of its kinetostatic properties are homogeneous with respect to all the directions.

<div class="definition">
  <div></div>

-   **Velocity isotropy**: A manipulator is isotropic with respect to the velocity, if it can perform the same velocity along all the directions.
-   **Force isotropy**: A manipulator is isotropic with respect to the force, if it can exert the same force along all the directions.
-   **Stiffness isotropy**: A manipulator is isotropic with respect to the stiffness, if the deflection of the TCP produced by a force applied to it is always in the direction of the force and its magnitude is independent of the force direction.
-   **Mass isotropy**: A manipulator is isotropic with respect to the equivalent gripper mass, if the acceleration of the TCP produced by a force applied to it is always in the direction of the force and its magnitude is independent of the force direction.

</div>

A 6-DoF spatial manipulator is isotropic with respect to velocity if:

\begin{equation}
J^T J = \diag(j\_{xx}, j\_{yy}, j\_{zz}, j\_{\alpha\alpha}, j\_{\beta\beta}, j\_{\gamma\gamma}) \quad \text{with} \quad j\_{xx}=j\_{yy}=j\_{zz} \quad \text{and} \quad j\_{\alpha\alpha}=j\_{\beta\beta}=j\_{\gamma\gamma}
\end{equation}

The same condition holds for the force isotropy.

Assuming that the actuators are locked and that they are the only sources of compliance, the force \\(F\_s\\) to be applied to the end effector to produce a motion \\(dS\\) is:

\begin{equation}
F\_s = \underbrace{J^T K\_q J}\_{K\_s} dS \quad K\_q = \diag(\dots,k\_i,\dots)
\end{equation}

where \\(k\_i\\) is the stiffness of the ith actuator.
A general 6-DoF manipulator is **fully isotropic** with respect to stiffness if:

\begin{equation}
K\_s = \diag(k\_{xx}, k\_{yy}, k\_{zz}, k\_{\alpha\alpha}, k\_{\beta\beta}, k\_{\gamma\gamma}) \quad \text{with} \quad k\_{xx}=k\_{yy}=k\_{zz}=k\_x \quad \text{and} \quad k\_{\alpha\alpha}=k\_{\beta\beta}=k\_{\gamma\gamma}=k\_\phi
\end{equation}

In this case, it results:

\begin{equation}
F = k\_x dX, \quad T = k\_\phi d\phi
\end{equation}

where \\(k\_x\\) is the translation stiffness and \\(k\_\phi\\) is the rotation stiffness.
This means that:

-   forces \\(F\\) applied to the TCP do not produce rotations \\(d\phi\\) but only translations \\(dX\\)
-   the translation is proportional to the force and parallel to it regardless to the force direction
-   torques \\(T\\) applied to the TCP do not produce translations \\(dx\\) but only rotations \\(d\phi\\)
-   the rotation is proportional to the torque and occurs around the same axis as the applied torque

In this special case in which all the actuators are identical to each other, and therefore have the same stiffness \\(k\\), we have \\(K\_s = kJ^TJ\\) and the condition number of the matrix \\(J^TJ\\) can be investigated instead of that of \\(J^T K\_q J\\).
In this case the isotropy for velocity, force and stiffness are achieve simultaneously.

A manipulator is **partially isotropic** if:

\begin{equation}
k\_{xx} = k\_{yy} \neq k\_{zz} \quad \text{and/or} \quad k\_{\alpha\alpha} = k\_{\beta\beta} \neq k\_{\gamma\gamma}
\end{equation}


### Point of isotropy {#point-of-isotropy}

A parallel manipulator as a "point of isotropy" if it exists at least one point of its end effector for which the isotropy condition is achieved.

Then conditions are given to find an isotropic TCP.


### Application to the Stewart platform {#application-to-the-stewart-platform}

Conditions can be applied to the Stewart platform and isotropy points can be found.


## ([Tong et al. 2011](#org0e02b02)) {#tong-et-al-dot-2011--org0e02b02}

A parallel manipulator consists of a movable platform, a fixed base, and six struts, each with a linear actuator.
The struts are partitioned into two groups: the first group with strut 1,3,5 and the second group with strut 2,4,6.
The attached points of each strut are uniformly spaced on the circumferences of two circles on the movable platform and the fixed base, respectively.
The three struts in each group are rotational symmetry and repeat every 120 deg.
This parallel manipulator with this kind of configurations are defined as generalized symmetric Gough-Stewart parallel manipulators (GSGSPMs).

<a id="orgc9be46b"></a>

{{< figure src="/ox-hugo/tong11_architecture_gsgspm.png" caption="Figure 1: Architecture of a GSGSPM" >}}

A compliance center exists consequentially for any GSGSPMs.
At the compliance center, a GSGSPM is uncoupled.


## ([Legnani et al. 2012](#org1e949d1)) {#legnani-et-al-dot-2012--org1e949d1}


## ([Ding et al. 2014](#org1fe4a1a)) {#ding-et-al-dot-2014--org1fe4a1a}


## ([Wu et al. 2018](#org7f6b447)) {#wu-et-al-dot-2018--org7f6b447}

> Isotropy => J\*J' = a\*I

<!--quoteend-->

> -   Stiffness isotropy = static isotropy
> -   velocity isotropy = kinematic isotropy

<!--quoteend-->

> They also proved that the symmetric generalized Stewart platform at a neutral position could be fully decoupled by adjusting the payload's center of mass to coincide with its **compliance center**. ([Tong et al. 2011](#org0e02b02))

<!--quoteend-->

> Dynamic isotropy => same resonance frequency for all suspension modes


## ([Zhou et al. 2019](#org1f33e66)) {#zhou-et-al-dot-2019--org1f33e66}


## ([Yang et al. 2020](#orgfee3e89)) {#yang-et-al-dot-2020--orgfee3e89}


## ([Kang et al. 2020](#org0ed4d48)) {#kang-et-al-dot-2020--org0ed4d48}



## Bibliography {#bibliography}

<a id="org89a27d1"></a>Bandyopadhyay, Sandipan, and Ashitava Ghosal. 2008. “An Algebraic Formulation of Kinematic Isotropy and Design of Isotropic 6-6 Stewart Platform Manipulators.” _Mechanism and Machine Theory_ 43 (5):591–616. <https://doi.org/10.1016/j.mechmachtheory.2007.05.003>.

<a id="org1fe4a1a"></a>Ding, Boyin, Benjamin S. Cazzolato, Richard M. Stanley, Steven Grainger, and John J. Costi. 2014. “Stiffness Analysis and Control of a Stewart Platform-Based Manipulator with Decoupled Sensor-Actuator Locations for Ultrahigh Accuracy Positioning under Large External Loads.” _Journal of Dynamic Systems, Measurement, and Control_ 136 (6):nil. <https://doi.org/10.1115/1.4027945>.

<a id="org2487ba1"></a>Fassi, Irene, Giovanni Legnani, and Diego Tosi. 2005. “Geometrical Conditions for the Design of Partial or Full Isotropic Hexapods.” _Journal of Robotic Systems_ 22 (10):507–18. <https://doi.org/10.1002/rob.20074>.

<a id="org0ed4d48"></a>Kang, Shengzheng, Hongtao Wu, Shengdong Yu, Yao Li, Xiaolong Yang, and Jiafeng Yao. 2020. “Modeling and Control of a Six-Axis Parallel Piezo-Flexural Micropositioning Stage with Cross-Coupling Hysteresis Nonlinearities.” In _2020 IEEE/ASME International Conference on Advanced Intelligent Mechatronics (AIM)_, 1350–55. IEEE.

<a id="org1e949d1"></a>Legnani, G., I. Fassi, H. Giberti, S. Cinquemani, and D. Tosi. 2012. “A New Isotropic and Decoupled 6-Dof Parallel Manipulator.” _Mechanism and Machine Theory_ 58 (nil):64–81. <https://doi.org/10.1016/j.mechmachtheory.2012.07.008>.

<a id="orgbf26550"></a>Legnani, Giovanni, D Tosi, I Fassi, Hermes Giberti, and Simone Cinquemani. 2010. “The ‘Point of Isotropy’ and Other Properties of Serial and Parallel Manipulators.” _Mechanism and Machine Theory_ 45 (10). Elsevier:1407–23.

<a id="org0e02b02"></a>Tong, Zhizhong, Jingfeng He, Hongzhou Jiang, and Guangren Duan. 2011. “Optimal Design of a Class of Generalized Symmetric Gough-Stewart Parallel Manipulators with Dynamic Isotropy and Singularity-Free Workspace.” _Robotica_ 30 (2):305–14. <https://doi.org/10.1017/s0263574711000531>.

<a id="org838fed0"></a>Tsai, K.Y., and K.D. Huang. 2003. “The Design of Isotropic 6-Dof Parallel Manipulators Using Isotropy Generators.” _Mechanism and Machine Theory_ 38 (11):1199–1214. <https://doi.org/10.1016/s0094-114x(03)00067-3>.

<a id="org7f6b447"></a>Wu, Ying, Kaiping Yu, Jian Jiao, Dengqing Cao, Weichao Chi, and Jie Tang. 2018. “Dynamic Isotropy Design and Analysis of a Six-Dof Active Micro-Vibration Isolation Manipulator on Satellites.” _Robotics and Computer-Integrated Manufacturing_ 49 (nil):408–25. <https://doi.org/10.1016/j.rcim.2017.08.003>.

<a id="orgfee3e89"></a>Yang, Xiaolong, Hongtao Wu, Yao Li, Shengzheng Kang, Bai Chen, Huimin Lu, Carman K. M. Lee, and Ping Ji. 2020. “Dynamics and Isotropic Control of Parallel Mechanisms for Vibration Isolation.” _IEEE/ASME Transactions on Mechatronics_ 25 (4):2027–34. <https://doi.org/10.1109/tmech.2020.2996641>.

<a id="org1f33e66"></a>Zhou, Songlin, Jing Sun, Weixing Chen, Wei Li, and Feng Gao. 2019. “Method of Designing a Six-Axis Force Sensor for Stiffness Decoupling Based on Stewart Platform.” _Measurement_ 148 (nil):106966. <https://doi.org/10.1016/j.measurement.2019.106966>.
